@@ -5,7 +5,7 @@ from typing import Dict, Optional
 import abc
 
 
-@dataclass
+@dataclass(frozen=True)
 class Command(metaclass=abc.ABCMeta):
     pass
 
@@ -16,6 +16,7 @@ class CommandHandler(metaclass=abc.ABCMeta):
         raise NotImplementedError
 
 
+@dataclass(frozen=True)
 class Query(metaclass=abc.ABCMeta):
     pass
 
