@@ -1,12 +1,13 @@
 from datetime import datetime
-from typing import List, Dict
+from typing import Dict, Optional, Any
 import json
 import abc
 
 
 class DomainEvent(metaclass=abc.ABCMeta):
-    def __init__(self):
+    def __init__(self, aggregate_id: Optional[Any] = None):
         self._occurred_on = datetime.now()
+        self._aggregate_id = aggregate_id
 
     @abc.abstractmethod
     def event_name(self) -> str:
@@ -16,6 +17,10 @@ class DomainEvent(metaclass=abc.ABCMeta):
     def occurred_on(self):
         return self._occurred_on
 
+    @property
+    def aggregate_id(self) -> Optional[Any]:
+        return self._aggregate_id
+
     def serialize(self) -> str:
         def json_converter(o):
             if isinstance(o, datetime):
@@ -39,30 +44,7 @@ class DomainEvent(metaclass=abc.ABCMeta):
         return "DomainEvent <{}>".format(self.event_name())
 
 
-class DomainEventPublisher:
-    def __init__(self, event_handlers: Dict):
-        self._event_handlers = event_handlers
-
-    def publish(self, domain_events: List[DomainEvent]) -> None:
-        for domain_event in domain_events:
-            self._publish_event(domain_event)
-
-    def _publish_event(self, domain_event: DomainEvent) -> None:
-        domain_event_name = _classname(domain_event)
-
-        event = self._event_handlers.get(domain_event_name)
-        subscribers = event.get('subscribers')
-
-        for subscriber in subscribers:
-            subscriber_class = subscriber()
-            subscriber_class.handle(domain_event)
-
-
-def _classname(obj):
-    cls = type(obj)
-    module = cls.__module__
-    name = cls.__qualname__
-    if module is not None and module != "__builtin__":
-        name = "{}.{}".format(module, name)
-
-    return name
+class Subscriber(metaclass=abc.ABCMeta):
+    @abc.abstractmethod
+    def handle(self, event: DomainEvent) -> None:
+        raise NotImplementedError
